import React from "react";
import { Link } from "gatsby";

import Header from "../components/header";
import RealisationCard from "../components/realisationCard";
import "../scss/index.scss";
import Footer from "../components/footer";
import Art from "../images/undraw_Art.svg";

const IndexPage = () => {
	return (
		<main>
			<title>CLI: Association du numérique</title>
			<Header />
			<div className="page-content">
				<section className="pages-sections">
					<p className="section-paragraph">
						La CLI est une association de travailleuses et travailleurs du
						numériques basée à Strasbourg. Notre catalogue de prestations se
						compose d'un large éventail de services comme le développement de
						sites web, leur mise en production et leur maintenance. Nous
						effectuons aussi la conception de solutions logiciels, l'assistance
						informatique, et la formation à divers outils informatiques.
					</p>
					<p className="section-paragraph">
						Nous proposons un accompagnement local et sur-mesure pour tous vos
						projets numériques.{" "}
						<span className="paragraph-highlight">
							Demandez nous un devis, nous vous répondrons au plus vite.
						</span>
					</p>
					<Link to="/nous-contacter" className="btn cta">
						<span>Contactez nous</span>
					</Link>
				</section>
				<section className="services-list">
					<div className="service-type">
						<div className="service-type-header">
							<p className="service-name">Développement web</p>
							<img
								src={Art}
								className="service-type-image"
								alt="random image"
							/>
						</div>
						<p className="service-description">
							Nous créons sur mesure le site dont vous avez besoin pour votre
							activité : e-commerce, blog, portfolio ...
						</p>
						<Link to="/vos-besoins#web-dev" className="service-link">
							<span> ... et plus encore !</span>
						</Link>
					</div>
					<div className="service-type">
						<div className="service-type-header">
							<p className="service-name">Développement applicatif</p>
							<img
								src={Art}
								className="service-type-image"
								alt="random image"
							/>
						</div>
						<p className="service-description">
							Besoin d'une application pour votre entreprise ? Nous sommes à
							l'écoute pour développer l'outil nécessaire ...
						</p>
						<Link to="/vos-besoins#app-dev" className="service-link">
							<span> ... et plus encore !</span>
						</Link>
					</div>
					<div className="service-type">
						<div className="service-type-header">
							<p className="service-name">Formations et assistance</p>
							<img
								src={Art}
								className="service-type-image"
								alt="random image"
							/>
						</div>
						<p className="service-description">
							Montez en compétence avec nos formations en bureautique ou au
							développement : CMS - Linux - Base de donnée SQL ...
						</p>
						<Link
							to="/vos-besoins#course-and-maintenance"
							className="service-link">
							<span> ... et plus encore !</span>
						</Link>
					</div>
					<div className="service-type">
						<div className="service-type-header">
							<p className="service-name">Réseau</p>
							<img
								src={Art}
								className="service-type-image"
								alt="random image"
							/>
						</div>
						<p className="service-description">
							Nous intervenons ou conceptualisons votre infrastructure réseau, à
							la fois hardware et software ...
						</p>
						<Link to="/vos-besoins#network" className="service-link">
							<span> ... et plus encore !</span>
						</Link>
					</div>
				</section>
				<section className="pages-sections made-by-us">
					<h3 className="section-title">Nos réalisations</h3>
					<div className="list-card">
						<RealisationCard
							cardName="pyHeatPump"
							cardDescription="Projet de remplacement du RPiPasserelle d'OTEC."
							techTag="Python"
						/>
						<RealisationCard
							cardName="Supervision"
							cardDescription="Interface graphique de gestion pour pyHeatPump."
							techTag="Python,Symphony"
						/>
						<RealisationCard
							cardName="Chronobriq"
							cardDescription="Un outil de gestion de comptabilité horaire."
							techTag="Ruby on Rails,React.js,Redux,React-intl"
						/>
					</div>
				</section>
			</div>
			<Footer />

			<noscript>fuck you</noscript>
		</main>
	);
};

export default IndexPage;
